@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2020 Canonical
+ * Copyright (C) 2014-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1116,7 +1116,7 @@ int main(int argc, char **argv)
 		goto tidy;
 	}
 
-	if (opt_flags & OPT_INPUT_FILE) {
+	if ((opt_flags & OPT_INPUT_FILE) && (in_filename != NULL)) {
 		struct stat buf;
 
 		fdin = open(in_filename, O_RDONLY);
